@@ -91,7 +91,18 @@ def docker_run(run_context: LocalRunContext):
     _docker_run_cmd_arg = f"/bin/bash -l -c {quoted_script}"
 
     dockercmd.extend(
-        ["--name", container_name, "-v", f"{_pwd}:/eo_workdir", "-w", "/eo_workdir"]
+        [
+            "--name",
+            container_name,
+            "-v",
+            f"{_pwd}:/eo_workdir",
+            "-w",
+            "/eo_workdir",
+            "-e",
+            f"EO_WORKDIR={_pwd}",
+            "-v",
+            "/var/run/docker.sock:/var/run/docker.sock",
+        ]
         + (
             ["-e", "LOCAL_UID=$(id -u $USER)", "-e", "LOCAL_GID=$(id -g $USER)"]
             if platform in ("linux", "linux2")
