@@ -11,7 +11,6 @@ import logging
 from os import getenv
 from embedops_cli.api import (
     Configuration,
-    DefaultApi as ApiClient,
     CIRunCreateProps,
     CIRunUpdateProps,
     rest,
@@ -95,30 +94,29 @@ class CIRun:
     def _update_ci_run(self, status_str):
 
         try:
+            api_client = get_client()
             configuration = Configuration()
             configuration.api_key["X-API-Key"] = self._settings.api_repo_key
             configuration.host = f"{self._settings.host}/api/v1"
 
-            # create an instance of the API class
-            api_instance = ApiClient(configuration)
             ci_run = CIRunUpdateProps()
             ci_run.status = status_str
             ci_run.pipeline_url = self._settings.job_url
-            updated_run = api_instance.update_ci_run_from_ci(
+            updated_run = api_client.update_ci_run_from_ci(
                 ci_run, self._settings.run_id
             )
 
             _logger.debug("Updated CI run:")
             _logger.debug(updated_run)
 
-            del api_instance  # kills the thread pool
+            del api_client  # kills the thread pool
         except AttributeError as exc:
             _logger.info("No API Repo Key provided. CI run will not be updated.")
             _logger.info(exc)
 
     @staticmethod
     def _previous_return():
-        return int(sys.stdin.readline())
+        return int(sys.argv[1])
 
     def finalize_ci_run(self):
         """Update the status of the current CI run based on the value of a standard in read"""
