@@ -165,6 +165,22 @@ class TestEntrypoint:
         self.ci_run_caller.assert_called_with("memusage", "abcd1234", "main")
         self.logger_mock.info.assert_called_with(expected_id)
 
+    def test_successful_call_with_job_name(self, monkeypatch):
+        monkeypatch.setenv("EMBEDOPS_JOB_NAME", "build_job")
+        expected_id = "yabbazabba"
+        new_ci_run = MagicMock()
+        new_ci_run.id = expected_id
+        self.ci_run_caller.return_value = new_ci_run
+        with pytest.raises(SystemExit) as pytest_wrapped_e:
+            create_entry()
+        assert pytest_wrapped_e.type == SystemExit
+        assert pytest_wrapped_e.value.code == 0
+
+        self.ci_run_caller.assert_called_with(
+            "memusage", "abcd1234", "main", "build_job"
+        )
+        self.logger_mock.info.assert_called_with(expected_id)
+
 
 from os import getenv
 import importlib
